@@ -1,11 +1,12 @@
 //! A helper module which contains functionality to run feasibility checks on solution.
 
 use vrp_pragmatic::checker::CheckerContext;
-use vrp_pragmatic::format::problem::{deserialize_matrix, deserialize_problem};
+use vrp_pragmatic::format::problem::{deserialize_matrix, deserialize_problem, PragmaticProblem};
 use vrp_pragmatic::format::solution::deserialize_solution;
 
 use std::io::{BufReader, Read};
 use std::process;
+use std::sync::Arc;
 use vrp_pragmatic::format::FormatError;
 
 /// Checks pragmatic solution feasibility.
@@ -36,5 +37,10 @@ pub fn check_pragmatic_solution<F: Read>(
             .collect::<Vec<_>>()
     });
 
-    CheckerContext::new(problem, matrices, solution).check()
+    let core_problem = Arc::new((problem.clone(), matrices.clone()).read_pragmatic().unwrap_or_else(|err| {
+        eprintln!("cannot read pragmatic problem: {}", FormatError::format_many(&err, ","));
+        process::exit(1);
+    }));
+
+    CheckerContext::new(core_problem, problem, matrices, solution).check()
 }
