@@ -17,20 +17,21 @@ use vrp_core::models::Problem;
 use vrp_core::solver::mutation::*;
 use vrp_core::solver::selection::NaiveSelection;
 use vrp_core::solver::{Builder, Telemetry, TelemetryMode};
+use vrp_core::utils::get_cpus;
 
 /// An algorithm configuration.
 #[derive(Clone, Deserialize, Debug)]
 pub struct Config {
     /// Specifies population configuration.
-    population: Option<PopulationConfig>,
+    pub population: Option<PopulationConfig>,
     /// Specifies mutation operator configuration.
-    selection: Option<SelectionConfig>,
+    pub selection: Option<SelectionConfig>,
     /// Specifies mutation operator configuration.
-    mutation: Option<MutationConfig>,
+    pub mutation: Option<MutationConfig>,
     /// Specifies algorithm termination configuration.
-    termination: Option<TerminationConfig>,
+    pub termination: Option<TerminationConfig>,
     /// Specifies telemetry configuration.
-    telemetry: Option<TelemetryConfig>,
+    pub telemetry: Option<TelemetryConfig>,
 }
 
 /// A population configuration.
@@ -61,13 +62,14 @@ pub struct SelectionConfig {
 /// A selection operator configuration.
 #[derive(Clone, Deserialize, Debug)]
 #[serde(tag = "type")]
+#[serde(rename_all = "camelCase")]
 pub enum SelectionType {
     #[serde(rename(deserialize = "naive"))]
     Naive {
         /// A name of selection operator.
         name: String,
         /// A size of offspring.
-        offspring_size: usize,
+        offspring_size: Option<usize>,
     },
 }
 
@@ -240,6 +242,12 @@ pub struct NameWeight {
     pub weight: usize,
 }
 
+impl Default for Config {
+    fn default() -> Self {
+        Self { population: None, selection: None, mutation: None, termination: None, telemetry: None }
+    }
+}
+
 fn configure_from_population(
     mut builder: Builder,
     population_config: &Option<PopulationConfig>,
@@ -272,7 +280,9 @@ fn configure_from_selection(
             .collection
             .iter()
             .map(|item| match item {
-                SelectionType::Naive { name, offspring_size } => (name, Arc::new(NaiveSelection::new(*offspring_size))),
+                SelectionType::Naive { name, offspring_size } => {
+                    (name, Arc::new(NaiveSelection::new(offspring_size.unwrap_or_else(get_cpus))))
+                }
             })
             .collect::<HashMap<_, _>>();
 
